@@ -3,6 +3,8 @@ from __future__ import print_function
 import numpy as np
 from scipy.special import gammainccinv, gammaincc
 
+__all__ = ['ConfidenceLevel']
+
 
 class ConfidenceLevel(object):
     """
@@ -60,7 +62,7 @@ class ConfidenceLevel(object):
 
     @ndim.setter
     def ndim(self, new_ndim):
-        if type(new_ndim) is not int:
+        if not isinstance(new_ndim, int):
             raise ValueError(
                 "Number of dimensions must be of type int! Received type: %s" % type(new_ndim))
         if new_ndim <= 0:
