@@ -3,6 +3,7 @@ import six
 import warnings
 
 from scipy.stats import poisson, norm, chi2
+from scipy.linalg import solve_triangular
 from ..io.file import FileIOMixin
 from .format import ParameterFormatter, CostFunctionFormatter
 
@@ -45,10 +46,12 @@ class CostFunction(FileIOMixin, object):
     EXCEPTION_TYPE = CostFunctionException
     _DATA_NAME = "data"
     _MODEL_NAME = "model"
-    _COV_MAT_INVERSE_NAME = "total_cov_mat_inverse"
+    _COV_MAT_CHOLESKY_NAME = "total_cov_mat_cholesky"
     _ERROR_NAME = "total_error"
 
-    def __init__(self, cost_function, arg_names=None, add_constraint_cost=True):
+    def __init__(
+            self, cost_function, arg_names=None, add_constraint_cost=True,
+            add_determinant_cost=False):
         """
         Construct :py:class:`CostFunction` object (a wrapper for a native Python function):
 
@@ -57,6 +60,9 @@ class CostFunction(FileIOMixin, object):
             If None, detect from function signature.
         :param bool add_constraint_cost: If :py:obj:`True`, automatically add the cost for kafe2
             constraints.
+        :param bool add_determinant_cost: If :py:obj:`True`, automatically increase the cost
+            function value by the logarithm of the determinant of the covariance matrix to reduce
+            bias.
         """
         self._cost_function_handle = cost_function
         _signature = signature(self._cost_function_handle)
@@ -90,6 +96,10 @@ class CostFunction(FileIOMixin, object):
         if self._add_constraint_cost:
             self._arg_names += ["parameter_values", "parameter_constraints"]
             self._arg_count += 2
+        self._add_determinant_cost = add_determinant_cost
+        if self._add_determinant_cost:
+            self._arg_names += ["total_cov_mat_log_determinant"]
+            self._arg_count += 1
 
         self._needs_errors = True
         self._is_chi2 = False
@@ -106,6 +116,11 @@ class CostFunction(FileIOMixin, object):
 
     def __call__(self, *args):
         additional_cost = 0.0
+        if self._add_determinant_cost:
+            _log_determinant = args[-1]
+            args = args[:-1]
+            if _log_determinant is not None:
+                additional_cost += _log_determinant
         if self._add_constraint_cost:
             _par_constraints = args[-1]
             _par_vals = args[-2]
@@ -155,6 +170,11 @@ class CostFunction(FileIOMixin, object):
         """Whether the cost function value is calculated from a saturated likelihood."""
         return self._saturated
 
+    @property
+    def add_determinant_cost(self):
+        """Whether the determinant cost is being added automatically to the cost function value."""
+        return self._add_determinant_cost
+
     def goodness_of_fit(self, *args):
         """How well the model agrees with the data."""
         try:
@@ -162,8 +182,12 @@ class CostFunction(FileIOMixin, object):
             _index_model = self._arg_names.index(self._MODEL_NAME)
         except ValueError:
             return None
+        if self._add_determinant_cost:
+            args = args[:-1] + (0.0,)
         _cost = self(*args)
         args = list(args)
+        if self._add_determinant_cost:
+            args = args[:-1]
         if self._add_constraint_cost:
             args = args[:-2]
         args[_index_model] = args[_index_data]
@@ -203,7 +227,8 @@ class CostFunction(FileIOMixin, object):
 
 class CostFunction_Chi2(CostFunction):
     def __init__(
-            self, errors_to_use='covariance', fallback_on_singular=True, add_constraint_cost=True):
+            self, errors_to_use='covariance', fallback_on_singular=True, add_constraint_cost=True,
+            add_determinant_cost=True):
         """Base class for built-in least-squares cost function.
 
         :param errors_to_use: Which errors to use when calculating :math:`\\chi^2`.
@@ -213,6 +238,9 @@ class CostFunction_Chi2(CostFunction):
             (or the errors are zero), calculate :math:`\\chi^2` as with ``errors_to_use=None``
         :param bool add_constraint_cost: If :py:obj:`True`, automatically add the cost for kafe2
             constraints.
+        :param bool add_determinant_cost: If :py:obj:`True`, automatically increase the cost
+            function value by the logarithm of the determinant of the covariance matrix to reduce
+            bias.
         """
 
         _cost_function_description = "chi-square"
@@ -224,7 +252,7 @@ class CostFunction_Chi2(CostFunction):
             _cost_function_description += " (no uncertainties)"
         elif errors_to_use.lower() == 'covariance':
             _chi2_func = self.chi2_covariance
-            _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._COV_MAT_INVERSE_NAME]
+            _arg_names = [self._DATA_NAME, self._MODEL_NAME, self._COV_MAT_CHOLESKY_NAME]
             self._fail_on_no_matrix = not fallback_on_singular
             self._fail_on_no_errors = True
             _cost_function_description += " (with covariance matrix)"
@@ -242,7 +270,8 @@ class CostFunction_Chi2(CostFunction):
         super(CostFunction_Chi2, self).__init__(
             cost_function=_chi2_func,
             arg_names=_arg_names,
-            add_constraint_cost=add_constraint_cost
+            add_constraint_cost=add_constraint_cost,
+            add_determinant_cost=add_determinant_cost
         )
 
         self._formatter.latex_name = "\\chi^2"
@@ -252,7 +281,7 @@ class CostFunction_Chi2(CostFunction):
         self._is_chi2 = True
         self._saturated = True
 
-    def _chi2(self, data, model, cov_mat_inverse=None, err=None):
+    def _chi2(self, data, model, cov_mat_cholesky=None, err=None):
         data = np.asarray(data)
         model = np.asarray(model)
 
@@ -264,10 +293,12 @@ class CostFunction_Chi2(CostFunction):
         _res = (data - model)
 
         # if a covariance matrix inverse is given, use it
-        if cov_mat_inverse is not None:
-            _cost = _res.dot(cov_mat_inverse).dot(_res)
-            if np.isnan(_cost):
-                _cost = np.inf
+        if cov_mat_cholesky is not None:
+            try:
+                _x = solve_triangular(cov_mat_cholesky, _res, lower=True)
+            except ValueError:
+                return np.inf
+            _cost = np.sum(np.square(_x))
             return _cost
 
         if self._fail_on_no_matrix:
@@ -311,27 +342,35 @@ class CostFunction_Chi2(CostFunction):
         """
         return self._chi2(data=data, model=model)
 
-    def chi2_covariance(self, data, model, total_cov_mat_inverse):
+    def chi2_covariance(self, data, model, total_cov_mat_cholesky):
         r"""A least-squares cost function calculated from `y` data and model values,
         considering the covariance matrix of the `y` measurements.
+        The cost function value can be calculated as follows:
 
         .. math::
-            C = \chi^2({\bf d}, {\bf m}) = ({\bf d} - {\bf m})^{\top}\,{{\bf V}^{-1}}\,({\bf d} - {\bf m})
+            C = \chi^2({\bf d}, {\bf m})
+            = ({\bf d} - {\bf m})^{\top}\,{{\bf V}^{-1}}\,({\bf d} - {\bf m})
                 +
-                C({\bf p})
+                C_{\rm con}({\bf p})
+                +
+                C_{\rm det}({\bf V})
 
         In the above, :math:`{\bf d}` are the measurements,
         :math:`{\bf m}` are the model predictions,
         :math:`{{\bf V}^{-1}}` is the inverse of the total covariance matrix,
-        and :math:`C({\bf p})` is the additional cost resulting from any constrained parameters.
+        :math:`C_{\rm con}({\bf p})` is the additional cost resulting from any constrained
+        parameters,
+        and :math:`C_{\rm det}({\bf V}) = \ln \det({\bf V})` is the additional cost to compensate
+        for a non-constant covariance matrix.
 
         :param data: measurement data :math:`{\bf d}`
         :param model: model predictions :math:`{\bf m}`
-        :param total_cov_mat_inverse: inverse of the total covariance matrix :math:`{\bf V}^{-1}`
+        :param total_cov_mat_cholesky: Cholesky decomposition  of the total covariance matrix
+            :math:`{\bf L}` with :math:`{\bf L}^T {\bf L} = {\bf V}`
 
         :return: cost function value
         """
-        return self._chi2(data=data, model=model, cov_mat_inverse=total_cov_mat_inverse)
+        return self._chi2(data=data, model=model, cov_mat_cholesky=total_cov_mat_cholesky)
 
     def chi2_pointwise_errors(self, data, model, total_error):
         r"""A least-squares cost function calculated from `y` data and model values,
@@ -355,7 +394,6 @@ class CostFunction_Chi2(CostFunction):
         """
         return self._chi2(data=data, model=model, err=total_error)
 
-
 class CostFunction_NegLogLikelihood(CostFunction):
     def __init__(self, data_point_distribution='poisson', ratio=False):
         r"""
@@ -403,7 +441,8 @@ class CostFunction_NegLogLikelihood(CostFunction):
 
         super(CostFunction_NegLogLikelihood, self).__init__(
             cost_function=_nll_func,
-            arg_names=_arg_names
+            arg_names=_arg_names,
+            add_determinant_cost=False
         )
 
         if ratio:
