@@ -1,4 +1,5 @@
 import abc
+import numpy  # help IDEs with type-hinting inside docstrings
 import numpy as np
 import six
 import textwrap
@@ -54,9 +55,11 @@ class Cycler(object):
                     _prop_size_i = len(_prop_vals)
                 else:
                     if len(_prop_vals) != _prop_size_i:
-                        raise CyclerException("Cannot cycle properties with mismatching value sequence lengths!")
+                        raise CyclerException("Cannot cycle properties with mismatching value "
+                                              "sequence lengths!")
                 if _prop_name in _processed_names:
-                    raise CyclerException("Cycle already contains a property named '%s'!" % (_prop_name,))
+                    raise CyclerException(
+                        "Cycle already contains a property named '%s'!" % (_prop_name,))
                 _prop_dict_i[_prop_name] = tuple(_prop_vals)
                 _processed_names.add(_prop_name)
             _pv_sizes.append(_prop_size_i)
@@ -79,7 +82,8 @@ class Cycler(object):
     # public methods
 
     def get(self, cycle_position):
-        _prop_positions = [(cycle_position//self._counter_divisors[i])%self._prop_val_sizes[i] for i in six.moves.range(self._dim)]
+        _prop_positions = [(cycle_position//self._counter_divisors[i]) % self._prop_val_sizes[i]
+                           for i in six.moves.range(self._dim)]
         _ps = {}
         for _i, _content in enumerate(self._props):
             for (_name, _values) in six.iteritems(_content):
@@ -125,21 +129,20 @@ class PlotAdapterException(Exception):
 
 @six.add_metaclass(abc.ABCMeta)
 class PlotAdapterBase(object):
-    """
-    This is a purely abstract class implementing the minimal interface required by all
+    """This is a purely abstract class implementing the minimal interface required by all
     types of plot adapters.
 
     A :py:obj:`PlotAdapter` object can be constructed for a :py:obj:`Fit` object of the
     corresponding type.
     Its main purpose is to provide an interface for accessing data stored in the
     :py:obj:`Fit` object, for the purposes of plotting.
-    Most importantly, it provides methods to call the relevant ``matplotlib`` methods
+    Most importantly, it provides methods to call the relevant :py:mod:`matplotlib` methods
     for plotting the data, model (and other information, depending on the fit type),
     and constructs the arrays required by these routines in a meaningful way.
 
-    Classes derived from :py:obj:`PlotAdapter` must at the very least contain
-    properties for constructing the ``x`` and ``y`` point arrays for both the
-    data and the fitted model, as well as methods calling the ``matplotlib`` routines
+    Classes derived from :py:class:`PlotAdapterBase` must at the very least contain
+    properties for constructing the *x* and *y* point arrays for both the
+    data and the fitted model, as well as methods calling the :py:mod:`matplotlib` routines
     doing the actual plotting.
     """
 
@@ -161,29 +164,30 @@ class PlotAdapterBase(object):
         ),
     )
 
-    def __init__(self, fit_object, axis_labels=(None, None)):
-        """
-        Construct a :py:obj:`PlotAdapter` for a :py:obj:`Fit` object:
+    AVAILABLE_X_SCALES = ('linear',)
+    AVAILABLE_Y_SCALES = ('linear', 'log')
 
-        :param fit_object: an object derived from :py:obj:`~kafe2.fit._base.FitBase`
-        :type fit_object: :py:class:`~kafe2.fit._base.FitBase`
-        :param axis_labels: The x- and y-axis labels as a tuple
-        :type axis_labels: tuple[str, str]
+    def __init__(self, fit_object):
+        """Construct a :py:obj:`PlotAdapter` for a :py:obj:`Fit` object:
+
+        :param fit_object: An object derived from :py:obj:`~.FitBase`
+        :type fit_object: kafe2.fit._base.FitBase
         """
         self._fit = fit_object
         self._x_range = None
         self._y_range = None
+        self._x_scale = 'linear'
+        self._y_scale = 'linear'
         _axes = ('x', 'y')
-        _axis_labels = []
-        for i, label in enumerate(axis_labels):
-            if label is None:  # check for label from init arguments
-                label = self._fit.data_container.axis_labels[i]
-                if label is None:  # check for dataset axis label
-                    label = kc_plot_style(self.PLOT_STYLE_CONFIG_DATA_TYPE, 'axis_labels', _axes[i])  # use default
+        _axis_labels = list()
+        for i, axis in enumerate(_axes):
+            label = self._fit.data_container.axis_labels[i]  # load from data_container
+            if label is None:  # fallback to default
+                label = kc_plot_style(self.PLOT_STYLE_CONFIG_DATA_TYPE, 'axis_labels', axis)
             if label == '__del__':  # set axis label to None for special string __del__
                 label = None
             _axis_labels.append(label)
-        self._axis_labels = tuple(_axis_labels)
+        self._axis_labels = _axis_labels
 
         # specification of subplots for which this adapter provided plot routines
         self._subplots = None
@@ -193,7 +197,11 @@ class PlotAdapterBase(object):
         self._set_plot_labels()
 
     def _get_subplots(self):
-        '''create dictionary containing all subplot specifications'''
+        """Create dictionary containing all subplot specifications.
+
+        :return: An ordered dictionary containing all information about the available plot methods.
+        :rtype: OrderedDict
+        """
         if not self._subplots:
             # create subplot dict
             self._subplots = OrderedDict()
@@ -228,14 +236,15 @@ class PlotAdapterBase(object):
         return self._subplots
 
     def _set_plot_labels(self):
-        """Obtain the labels from data and model container and set them accordingly"""
+        """Obtain the data and model labels from data and model container and set them
+        accordingly.
+        """
         if self._fit.data_container.label is not None:
             try:
                 self.update_plot_kwargs('data', dict(label=self._fit.data_container.label))
             except ValueError:
                 pass  # no data present
         if self._fit.model_label is not None:
-            # setting those in the derived classes would cause lots of duplicates, do it here for now
             for plot_model_name in ('model', 'model_line'):
                 try:
                     self.update_plot_kwargs(plot_model_name, dict(label=self._fit.model_label))
@@ -249,7 +258,7 @@ class PlotAdapterBase(object):
                 pass  # no error band available
 
     def _get_subplot_kwargs(self, plot_index, plot_type):
-        '''resolve the keyword arguments passed to the plot method'''
+        """Resolve the keyword arguments passed to the plot method."""
         _subplots = self._get_subplots()
 
         _explicit_kwargs = _subplots[plot_type].get('plot_method_keywords', {})
@@ -306,21 +315,12 @@ class PlotAdapterBase(object):
             return None
         return _total_err
 
-    def get_axis_labels(self):
-        """Get the axis labels used with this Plot Adapter.
-
-        :return: Tuple containing the axis labels.
-        :rtype: tuple[str or None, str or None]
-        """
-        return self._axis_labels
-
     # -- public API
 
     def call_plot_method(self, plot_type, target_axes, **kwargs):
-        """
-        Call the registered plot method for `plot_type`.
+        """Call the registered plot method for `plot_type`.
 
-        :param plot_type: key identifying a registered plot type for this `PlotAdapter`
+        :param plot_type: key identifying a registered plot type for this :py:obj:`PlotAdapter`
         :type plot_type: str
         :param target_axes: axes to plot to
         :type target_axes: `matplotlib.Axes` object
@@ -350,14 +350,16 @@ class PlotAdapterBase(object):
                 "is not callable!".format(
                     type(_callable), plot_type))
 
+        if kwargs.pop('hide', False):
+            return None
+
         return _callable(
             target_axes=target_axes,
             **kwargs
         )
 
     def update_plot_kwargs(self, plot_type, plot_kwargs):
-        """
-        Update the value of keyword arguments `plot_kwargs` to be passed
+        """Update the value of keyword arguments `plot_kwargs` to be passed
         to the plot method for for `plot_type`.
 
         If a keyword argument should be removed, the value of the keyword
@@ -365,11 +367,10 @@ class PlotAdapterBase(object):
         To indicate that the default value should be used, the special
         value ``'__default__'`` can be set as a value.
 
-        :param plot_type: key identifying a registered plot type for this `PlotAdapter`
+        :param plot_type: key identifying a registered plot type for this :py:obj:`PlotAdapter`
         :type plot_type: str
         :param plot_kwargs: dictionary containing keywords arguments to override
         :type plot_kwargs: dict
-        :return:
         """
         _subplots = self._get_subplots()
 
@@ -398,87 +399,78 @@ class PlotAdapterBase(object):
     @property
     @abc.abstractmethod
     def data_x(self):
-        """
-        The 'x' coordinates of the data (used by :py:meth:`~plot_data`).
+        """The *x* coordinates of the data (used by :py:meth:`~plot_data`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def data_y(self):
-        """
-        The 'y' coordinates of the data (used by :py:meth:`~plot_data`).
+        """The *y* coordinates of the data (used by :py:meth:`~plot_data`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def data_xerr(self):
-        """
-        The magnitude of the data 'x' error bars (used by :py:meth:`~plot_data`).
+        """The magnitude of the data *x* error bars (used by :py:meth:`~plot_data`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def data_yerr(self):
-        """
-        The magnitude of the data 'y' error bars (used by :py:meth:`~plot_data`).
+        """The magnitude of the data *y* error bars (used by :py:meth:`~plot_data`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def model_x(self):
-        """
-        The 'x' coordinates of the model (used by :py:meth:`~plot_model`).
+        """The *x* coordinates of the model (used by :py:meth:`~plot_model`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def model_y(self):
-        """
-        The 'y' coordinates of the model (used by :py:meth:`~plot_model`).
+        """The *y* coordinates of the model (used by :py:meth:`~plot_model`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def model_xerr(self):
-        """
-        The magnitude of the model 'x' error bars (used by :py:meth:`~plot_model`).
+        """The magnitude of the model *x* error bars (used by :py:meth:`~plot_model`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     @abc.abstractmethod
     def model_yerr(self):
-        """
-        The magnitude of the model 'y' error bars (used by :py:meth:`~plot_model`).
+        """The magnitude of the model *y* error bars (used by :py:meth:`~plot_model`).
 
-        :return: iterable
+        :rtype: numpy.ndarray
         """
         pass
 
     @property
     def x_range(self):
-        """
-        The 'x' axis plot range.
+        """The *x* axis plot range.
 
         :rtype: tuple[float, float]
         """
@@ -486,12 +478,11 @@ class PlotAdapterBase(object):
 
     @x_range.setter
     def x_range(self, x_range):
-        self._x_range = x_range
+        self._x_range = tuple(x_range)
 
     @property
     def y_range(self):
-        """
-        The 'y' axis plot range.
+        """The *y* axis plot range.
 
         :rtype: tuple[float, float]
         """
@@ -499,44 +490,104 @@ class PlotAdapterBase(object):
 
     @y_range.setter
     def y_range(self, y_range):
-        self._y_range = y_range
+        self._y_range = tuple(y_range)
+
+    @property
+    def x_scale(self):
+        """The *x* axis scale. Available scales are given in :py:const:`~.AVAILABLE_X_SCALES`
+
+        :rtype: str
+        """
+        return self._x_scale
+
+    @x_scale.setter
+    def x_scale(self, scale):
+        if scale not in self.AVAILABLE_X_SCALES:
+            raise PlotAdapterException("x_scale {} is not supported for this type of fit, "
+                                       "use one of {}".format(scale, self.AVAILABLE_X_SCALES))
+        self._x_scale = scale
+
+    @property
+    def y_scale(self):
+        """The *y* axis scale. Available scales are given in :py:const:`~.AVAILABLE_Y_SCALES`
+
+        :rtype: str
+        """
+        return self._y_scale
+
+    @y_scale.setter
+    def y_scale(self, scale):
+        if scale not in self.AVAILABLE_Y_SCALES:
+            raise PlotAdapterException("y_scale {} is not supported for this type of fit, "
+                                       "use one of {}".format(scale, self.AVAILABLE_Y_SCALES))
+        self._y_scale = scale
+
+    @property
+    def x_label(self):
+        """The *x* axis label of the fit handled by this plot adapter. If ``'__del__'`` is used,
+        the label will be set to :py:obj:`None`.
+
+        :rtype: str
+        """
+        return self._axis_labels[0]
+
+    @x_label.setter
+    def x_label(self, label):
+        if label == '__del__':
+            label = None
+        self._axis_labels[0] = label
+
+    @property
+    def y_label(self):
+        """The *x* axis label of the fit handled by this plot adapter. If ``'__del__'`` is used,
+        the label will be set to :py:obj:`None`.
+
+        :rtype: str
+        """
+        return self._axis_labels[1]
+
+    @y_label.setter
+    def y_label(self, label):
+        if label == '__del__':
+            label = None
+        self._axis_labels[1] = label
 
     @abc.abstractmethod
     def plot_data(self, target_axes, **kwargs):
-        """
-        Method called by the main plot routine to plot the data points to a specified matplotlib ``Axes`` object.
+        """Method called by the main plot routine to plot the data points to a specified
+        :py:class:`matplotlib.axes.Axes` object.
 
-        :param target_axes: ``matplotlib`` ``Axes`` object
+        :param matplotlib.axes.Axes target_axes: The :py:mod:`matplotlib` target axes.
         :return: plot handle(s)
         """
         pass
 
     @abc.abstractmethod
     def plot_model(self, target_axes, **kwargs):
-        """
-        Method called by the main plot routine to plot the model to a specified matplotlib ``Axes`` object.
+        """Method called by the main plot routine to plot the model to a specified
+        :py:class:`matplotlib.axes.Axes` object.
 
-        :param target_axes: ``matplotlib`` ``Axes`` object
+        :param matplotlib.axes.Axes target_axes: The :py:mod:`matplotlib` target axes.
         :return: plot handle(s)
         """
         pass
 
     @abc.abstractmethod
     def plot_ratio(self, target_axes, **kwargs):
-        """
-        Method called by the main plot routine to plot the data/model ratio to a specified matplotlib ``Axes`` object.
+        """Method called by the main plot routine to plot the data/model ratio to a specified
+        :py:class:`matplotlib.axes.Axes` object.
 
-        :param target_axes: ``matplotlib`` ``Axes`` object
+        :param matplotlib.axes.Axes target_axes: The :py:mod:`matplotlib` target axes.
         :return: plot handle(s)
         """
         pass
 
-    #Overridden by multi plot adapters
+    # Overridden by multi plot adapters
     def get_formatted_model_function(self, **kwargs):
         """return model function string"""
         return self._fit.model_function.formatter.get_formatted(**kwargs)
 
-    #Overridden by multi plot adapters
+    # Overridden by multi plot adapters
     @property
     def model_function_parameter_formatters(self):
         """The model function parameter formatters, excluding the independent variable."""
@@ -691,14 +742,15 @@ class Plot(object):
 
                 _axes_plots = _axes_plot_dicts.setdefault('plots', [])
 
-                _artist = _pdc.call_plot_method(
-                    _pt,
-                    target_axes=self._get_axes(_axes_key),
-                    **_pdc._get_subplot_kwargs(
-                        _i_pdc,
-                        _pt
-                    )
-                )
+                _plot_kwargs = _pdc._get_subplot_kwargs(_i_pdc, _pt)
+                if 'zorder' not in _plot_kwargs:
+                    _plot_kwargs['zorder'] = 0
+                _plot_kwargs['zorder'] = _plot_kwargs['zorder'] - 10*_i_pdc
+
+                _artist = _pdc.call_plot_method(_pt,
+                                                target_axes=self._get_axes(_axes_key),
+                                                **_plot_kwargs
+                                                )
 
                 _axes_plots.append({
                     'type' : _pt,
@@ -741,10 +793,7 @@ class Plot(object):
 
         _ndf = plot_adapter._fit.ndf
         _cost_function_value = plot_adapter._fit.cost_function_value
-        if plot_adapter._fit._cost_function.saturated:
-            _gof_value = _cost_function_value
-        else:
-            _gof_value = plot_adapter._fit.goodness_of_fit
+        _gof_value = plot_adapter._fit.goodness_of_fit
         _info_format_dict = dict(
             model_function=plot_adapter.get_formatted_model_function(
                 with_par_values=False,
@@ -799,16 +848,15 @@ class Plot(object):
             _multi_ndf = self._multifit.ndf
             _multi_cost_function = self._multifit._cost_function
             _multi_cost_function_value = self._multifit.cost_function_value
+            _multi_gof = self._multifit.goodness_of_fit
 
             _multi_info_dict = dict()
             if _multi_cost_function.is_chi2:
-                _multi_gof = _multi_cost_function_value
                 _template = "    $\\hookrightarrow$ global {fit_quality}\n"
                 _multi_info_dict["chi2_probability"] = self._multifit.chi2_probability
                 _template += "    $\\hookrightarrow$ global $\\chi^2 \\, \\mathrm{{probability}} " \
                              "= {chi2_probability:%s}$" % _float_template
             elif _multi_cost_function.saturated:
-                _multi_gof = _multi_cost_function_value
                 _template = "    $\\hookrightarrow$ global cost / ndf = {fit_quality}\n"
             else:
                 _template = "    $\\hookrightarrow$ global cost = {cost}\n"
@@ -817,7 +865,6 @@ class Plot(object):
                     with_name=False,
                     format_as_latex=format_as_latex
                 )
-                _multi_gof = self._multifit.goodness_of_fit
                 if _multi_gof is not None:
                     _template += "    $\\hookrightarrow$ global GoF / ndf = {fit_quality}\n"
 
@@ -847,6 +894,8 @@ class Plot(object):
 
             _prev_fit_index = None
             _fit_info = {}
+            if isinstance(fit_info, bool):
+                fit_info = [fit_info] * len(self._fits)
             for _i_plot, _plot_dict in enumerate(_axes_plots):
                 # check if artist available for this plot
                 try:
@@ -866,16 +915,15 @@ class Plot(object):
                 _ls_sorted.append(_ls_unsorted[_artist_index])
 
                 # if requested, compute info of fit associated to this artist
-                if fit_info:
-                    _fit_index = _plot_dict['fit_index']
-
-                    # compute fit info string (if not computed yet)
+                _fit_index = _plot_dict['fit_index']
+                if fit_info[_fit_index]:
                     if _fit_index not in _fit_info:
+                        # compute fit info string (if not computed yet)
                         _fit_info[_fit_index] = dict(
                             text=self._get_fit_info(
                                 _plot_dict['adapter'],
                                 format_as_latex=True,
-                                asymmetric_parameter_errors=asymmetric_parameter_errors
+                                asymmetric_parameter_errors=asymmetric_parameter_errors,
                             )
                         )
 
@@ -933,21 +981,24 @@ class Plot(object):
                 _ax.set_ylim(_ylim)
 
     def _set_axis_labels(self, plot_results, axes_keys):
-        '''set the x and y axis labels'''
+        """Set the x and y axis labels from given plot adapter labels"""
         for _axes_name, _axes_dict in six.iteritems(plot_results):
             _ax = self._get_axes(_axes_name)
 
             # collect different sets of axis labels
-            _seen_labels = []
+            _seen_x_labels = list()
+            _seen_y_labels = list()
             for _plot in _axes_dict['plots']:
+                _x_label = _plot['adapter'].x_label
+                _y_label = _plot['adapter'].y_label
+                if _x_label not in _seen_x_labels:
+                    _seen_x_labels.append(_x_label)
+                if _y_label not in _seen_y_labels:
+                    _seen_y_labels.append(_y_label)
 
-                _labels = _plot['adapter'].get_axis_labels()
-                if _labels not in _seen_labels:
-                    _seen_labels.append(_labels)
-
-            # use concatenation of labels as axis label
-            _ax.set_xlabel(', '.join(filter(None, [_l[0] for _l in _seen_labels])))  # use filter to skip None labels
-            _ax.set_ylabel(', '.join(filter(None, [_l[1] for _l in _seen_labels])))  # use filter to skip None labels
+            # use concatenation of labels as axis label, filter to skip None labels
+            _ax.set_xlabel(', '.join(filter(None, [label for label in _seen_x_labels])))
+            _ax.set_ylabel(', '.join(filter(None, [label for label in _seen_y_labels])))
 
         # hide x tick labels in all but the lowest axes
         for _key in axes_keys[:-1]:
@@ -970,46 +1021,120 @@ class Plot(object):
 
     @property
     def x_range(self):
+        """The plotting x-range for each fit handled by this :py:obj:`~kafe2.Plot` object.
+        :param: List of tuples containing the x_ranges for each fit.
+        :type: list[tuple[float, float]] or tuple[float, float]
+        """
         return [_adapter.x_range for _adapter in self._get_plot_adapters()]
 
     @x_range.setter
     def x_range(self, x_range):
-        """The plotting x-range for each fit handled by this :py:obj:`~kafe2.Plot` object.
-        :param x_range: Iterable of tuples containing the x_ranges for each fit.
-        :type x_range: Iterable[tuple[float, float]] or tuple[float, float]"""
         _adapters = self._get_plot_adapters()
         if np.ndim(x_range) == 1:
             if len(x_range) != 2:
-                raise PlotFigureException("x_range must contain two elements. A lower and an upper limit. Got {} "
-                                          "elements".format(len(x_range)))
+                raise PlotFigureException("x_range must contain two elements. "
+                                          "A lower and an upper limit. Got {} elements"
+                                          .format(len(x_range)))
             x_range = itertools.repeat(x_range, len(_adapters))
         elif len(_adapters) != len(x_range):
-            raise PlotFigureException("Amount of x_ranges and fits does not match. Got {} x_ranges and have {} "
-                                      "fits".format(len(x_range), len(_adapters)))
+            raise PlotFigureException("Amount of x_ranges and fits does not match. "
+                                      "Got {} x_ranges and have {} fits"
+                                      .format(len(x_range), len(_adapters)))
         for i, _range in enumerate(x_range):
             _adapters[i].x_range = _range
 
     @property
     def y_range(self):
+        """The plotting y-range for each fit handled by this :py:obj:`~kafe2.Plot` object.
+        :param: List of tuples containing the y_ranges for each fit.
+        :type: list[tuple[float, float]] or tuple[float, float]
+        """
         return [_adapter.y_range for _adapter in self._get_plot_adapters()]
 
     @y_range.setter
     def y_range(self, y_range):
-        """Set the plotting y-range for each fit handled by this :py:obj:`~kafe2.Plot` object.
-        :param y_range: Iterable of tuples containing the y_ranges for each fit.
-        :type y_range: Iterable[tuple[float, float]] or tuple[float, float]"""
         _adapters = self._get_plot_adapters()
         if np.ndim(y_range) == 1:
             if len(y_range) != 2:
-                raise PlotFigureException("y_range must contain two elements. A lower and an upper limit. Got {} "
-                                          "elements".format(len(y_range)))
+                raise PlotFigureException("y_range must contain two elements. "
+                                          "A lower and an upper limit. Got {} elements"
+                                          .format(len(y_range)))
             y_range = itertools.repeat(y_range, len(_adapters))
         elif len(_adapters) != len(y_range):
-            raise PlotFigureException("Amount of y_ranges and fits does not match. Got {} y_ranges and have {} "
-                                      "fits".format(len(y_range), len(_adapters)))
+            raise PlotFigureException("Amount of y_ranges and fits does not match. "
+                                      "Got {} y_ranges and have {} fits"
+                                      .format(len(y_range), len(_adapters)))
         for i, _range in enumerate(y_range):
             _adapters[i].y_range = _range
 
+    def _repeat_str(self, var):
+        """Repeat a string with the count of the given plot adapters. Used by setters."""
+        _adapters = self._get_plot_adapters()
+        if isinstance(var, str):  # check if string, if not probably list
+            var = itertools.repeat(var, len(_adapters))
+        elif len(_adapters) != len(var):
+            raise PlotFigureException("Length of input and fits does not match. "
+                                      "Got {} inputs and have {} fits"
+                                      .format(len(var), len(_adapters)))
+        return var
+
+    @property
+    def x_scale(self):
+        """The x-scale for each fit used for creating the support values when plotting and axis
+        scaling.
+        :type: list[str] or str
+        """
+        return [_adapter.x_scale for _adapter in self._get_plot_adapters()]
+
+    @x_scale.setter
+    def x_scale(self, x_scale):
+        x_scale = self._repeat_str(x_scale)
+        for adapter, _scale in zip(self._get_plot_adapters(), x_scale):
+            adapter.x_scale = _scale
+
+    @property
+    def y_scale(self):
+        """The y-scale for each fit used when plotting.
+        :type: list[str] or str
+        """
+        return [_adapter.y_scale for _adapter in self._get_plot_adapters()]
+
+    @y_scale.setter
+    def y_scale(self, y_scale):
+        y_scale = self._repeat_str(y_scale)
+        for adapter, _scale in zip(self._get_plot_adapters(), y_scale):
+            adapter.y_scale = _scale
+
+    @property
+    def x_label(self):
+        """The x-label(s) of the plot. If multiple fits are handled by this plot this is a list of
+        strings. Multiple labels will be separated by a comma in the final plot while skipping
+        duplicates.
+        If a label is :py:obJ:`None` or ``'__del__'`` it will be removed.
+        :type: str or list[str]"""
+        return [_adapter.x_label for _adapter in self._get_plot_adapters()]
+
+    @x_label.setter
+    def x_label(self, label):
+        label = self._repeat_str(label)
+        for _l, adapter in zip(label, self._get_plot_adapters()):
+            adapter.x_label = _l
+
+    @property
+    def y_label(self):
+        """The y-label(s) of the plot. If multiple fits are handled by this plot this is a list of
+        strings. Multiple labels will be separated by a comma in the final plot while skipping
+        duplicates.
+        If a label is :py:obJ:`None` or ``'__del__'`` it will be removed.
+        :type: str or list[str]"""
+        return [_adapter.y_label for _adapter in self._get_plot_adapters()]
+
+    @y_label.setter
+    def y_label(self, label):
+        label = self._repeat_str(label)
+        for _l, adapter in zip(label, self._get_plot_adapters()):
+            adapter.y_label = _l
+
     # -- public methods
 
     def plot(self, legend=True, fit_info=True, asymmetric_parameter_errors=False, ratio=False, ratio_range=None,
@@ -1018,7 +1143,10 @@ class Plot(object):
         Plot data, model (and other subplots) for all child :py:obj:`Fit` objects.
 
         :param legend: if ``True``, a legend is rendered
-        :param fit_info: if ``True``, fit results will be shown in the legend
+        :param fit_info: If :py:obj:`True`, fit results will be shown in the legend. This can also
+            be a list of booleans, corresponding to the fits handled by this
+            :py:obj:`~.Plot`-object.
+        :type legend: bool or typing.Collection[bool]
         :param asymmetric_parameter_errors: if ``True``, parameter errors in fit results will be asymmetric
         :param ratio: if ``True``, a secondary plot containing data/model ratios is shown below the main plot
         :param ratio_range: the *y* range to set in the secondary plot
@@ -1054,6 +1182,10 @@ class Plot(object):
 
                 _plot_results = self._plot_and_get_results(plot_indices=(i,) if self._separate_figs else None)
 
+                # set axis scales for the main plot, x-axis is shared with ratio plot
+                self._get_axes('main').set_xscale(self.x_scale[i])
+                self._get_axes('main').set_yscale(self.y_scale[i])
+
                 if legend:
                     self._render_legend(plot_results=_plot_results, axes_keys=('main',), fit_info=fit_info,
                                         asymmetric_parameter_errors=asymmetric_parameter_errors)
