@@ -1,6 +1,6 @@
 import numpy as np
 
-from .._base import PlotAdapterBase, PlotAdapterException, Plot
+from .._base import PlotAdapterBase, PlotAdapterException
 from .._aux import step_fill_between
 
 
@@ -45,8 +45,8 @@ class IndexedPlotAdapter(PlotAdapterBase):
 
     @property
     def data_yerr(self):
-        """y error bars for data: total data uncertainty"""
-        return self._fit.data_error
+        """y error bars for data: total uncertainty"""
+        return self._fit.total_error
 
     @property
     def model_x(self):
