@@ -1,10 +1,12 @@
 import numpy as np
 import six
+import sys
 import matplotlib as mpl
 
 from ...config import kafe2_rc
 from ...core.confidence import ConfidenceLevel
 from .._base import FitBase
+from .._base.format import ScalarFormatter as ScalarBaseFormatter
 from matplotlib import pyplot as plt, rcParams
 from matplotlib import gridspec as gs
 from matplotlib import ticker as plticker
@@ -14,6 +16,9 @@ from matplotlib import rc_context
 
 __all__ = ["ContoursProfiler"]
 
+_python_version = sys.version_info[0]
+_float_template = ".2g" if _python_version == 2 else "#.2g"
+
 
 def _linear_range_transform(range_, factor, asymmetry=0.0):
     """Return a range that is `factor` larger than `range_`.
@@ -95,18 +100,11 @@ class ScalarFormatter(plticker.Formatter):
         :param float sigma: The uncertainty of the parameter.
         :param int n_significant_digits: Number of significant digits.
         """
-        self._sigma = sigma
-        self._n_significant_digits = n_significant_digits
+        self.formatter = ScalarBaseFormatter(sigma=sigma, n_significant_digits=n_significant_digits)
 
     def __call__(self, x, pos=None):
         """Return the format for tick val *x* at position *pos*"""
-        _sig = int(-np.floor(np.log10(self._sigma))) + self._n_significant_digits - 1
-        _numeric_label = np.round(x, _sig)
-        return str(_numeric_label)
-
-    def format_data_short(self, value):
-        """Short version of format string for tick"""
-        return self.__call__(value)
+        return self.formatter(x)
 
 
 class ContoursProfilerException(Exception):
@@ -379,13 +377,14 @@ class ContoursProfiler(object):
                                                      label="fit minimum")
 
             if label_fit_minimum:
+                sigma_str = r"$\sigma_{{{}}} = {:%s}$" % _float_template
                 _axes.annotate(
                     '\n'.join([
                         r"$\langle {}\rangle = {}$".format(
                             _par_formatted_name.strip('$'),
-                            ScalarFormatter(_par_err, n_significant_digits=2)(_par_val)
+                            ScalarBaseFormatter(_par_err, n_significant_digits=2)(_par_val)
                         ),
-                        r"$\sigma_{{{}}} = {:.2g}$".format(
+                        sigma_str.format(
                             _par_formatted_name.strip('$'),
                             _par_err
                         )]),
