@@ -1,8 +1,8 @@
 import numpy as np
 from matplotlib.collections import LineCollection
-import warnings
 
 from .._base import PlotAdapterBase, PlotAdapterException
+from .._aux import add_pad_to_range
 
 
 __all__ = ["UnbinnedPlotAdapter"]
@@ -20,10 +20,12 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         PlotAdapterBase.PLOT_SUBPLOT_TYPES,
         model_line=dict(
             plot_adapter_method='plot_model_line',
-            target_axes='main'
+            target_axes='main',
         )
     )
-    del PLOT_SUBPLOT_TYPES['model']  # don't show "model" points
+    PLOT_SUBPLOT_TYPES['model']['hide'] = True  # don't show "model" points
+
+    AVAILABLE_X_SCALES = ('linear', 'log')
 
     def __init__(self, unbinned_fit_object):
         """
@@ -32,28 +34,13 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         """
         super(UnbinnedPlotAdapter, self).__init__(fit_object=unbinned_fit_object)
         self.n_plot_points = 100 if len(self.data_x) < 100 else len(self.data_x)
-        self.x_range = self._compute_plot_range_x()
-        self.y_range = self._compute_plot_range_y()
 
-    # -- private methods
+        self.x_range = add_pad_to_range(self._fit.data_range, scale=self.x_scale)
+        _y = self.model_line_y
+        _y_range = np.amin(_y), np.amax(_y)
+        self.y_range = add_pad_to_range(_y_range, scale=self.y_scale)
 
-    def _compute_plot_range_x(self, pad_coeff=1.1, additional_pad=None):
-        if additional_pad is None:
-            additional_pad = (0, 0)
-        _xmin, _xmax = self._fit.data_range
-        _w = _xmax - _xmin
-        return (0.5 * (_xmin + _xmax - _w * pad_coeff) - additional_pad[0],
-                0.5 * (_xmin + _xmax + _w * pad_coeff) + additional_pad[1])
-
-    def _compute_plot_range_y(self, pad_coeff=1.1, additional_pad=None):
-        if additional_pad is None:
-            additional_pad = (0, 0)
-        model = self.model_y
-        _ymax = np.nanmax(model[model != np.inf])
-        # no negative densities possible, ymin has to be 0, for data density to show
-        _ymin = 0
-        _w = _ymax - _ymin
-        return _ymin, 0.5 * (_ymin + _ymax + _w * pad_coeff) + additional_pad[1]
+    # -- public properties
 
     @property
     def data_x(self):
@@ -105,7 +92,17 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
     def model_line_x(self):
         """x support values for model function"""
         _xmin, _xmax = self.x_range
-        return np.linspace(_xmin, _xmax, self.n_plot_points)
+        if self.x_scale == 'linear':
+            return np.linspace(_xmin, _xmax, self.n_plot_points)
+        if self.x_scale == 'log':
+            try:
+                return np.geomspace(_xmin, _xmax, self.n_plot_points)
+            except ValueError:
+                raise UnbinnedPlotAdapterException("Support point calculation failed. "
+                                                   "The plot range can't include 0 when using log "
+                                                   "scale.")
+        raise UnbinnedPlotAdapterException("x_range has to be one of {}. Found {} instead.".format(
+            self.AVAILABLE_X_SCALES, self.x_scale))
 
     @property
     def model_line_y(self):
@@ -135,27 +132,12 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         """
         return None
 
-    @property
-    def x_range(self):
-        return self._x_range
-
-    @x_range.setter
-    def x_range(self, x_range):
-        if x_range is None:  # needed for model_line_x
-            warnings.warn("x_range can't be None, using defaults")
-            x_range = self._compute_plot_range_x()
-        self._x_range = x_range
-
-    @property
-    def y_range(self):
-        return self._y_range
-
-    @y_range.setter
-    def y_range(self, y_range):
-        if y_range is None:  # needed for plot_data
-            warnings.warn("y_range can't be None, using defaults")
-            y_range = self._compute_plot_range_y()
-        self._y_range = y_range
+    @PlotAdapterBase.x_scale.setter
+    def x_scale(self, scale):
+        update_xrange = self.x_range == add_pad_to_range(self._fit.data_range, scale=self.x_scale)
+        PlotAdapterBase.x_scale.fset(self, scale)  # use parent setter
+        if update_xrange:
+            self.x_range = add_pad_to_range(self._fit.data_range, scale=self.x_scale)
 
     # public methods
     def plot_data(self, target_axes, height=None, **kwargs):
@@ -170,10 +152,14 @@ class UnbinnedPlotAdapter(PlotAdapterBase):
         kwargs.pop('marker', None)  # pop marker keyword, as LineCollection doesn't support it
 
         if height is None:
-            height = self.y_range[1]/10  # set height to 1/10th of the max height of the model
+            if self.y_scale == 'linear':
+                height = self.y_range[1]/10  # set height to 1/10th of the max height of the model
+            elif self.y_scale == 'log':
+                height = 10**(np.log10(self.y_range[1])/10)
 
         data = self.data_x
-        xy_pairs = np.column_stack([np.repeat(data, 2), np.tile([0, height], len(data))])
+        xy_pairs = np.column_stack([np.repeat(data, 2),
+                                    np.tile([self.y_range[0], height], len(data))])
         lines = xy_pairs.reshape([len(data), 2, 2])
         line_segments = LineCollection(lines, **kwargs)
         return target_axes.add_collection(line_segments)
