@@ -213,8 +213,8 @@ class TestHistFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self._test_parameters_default_simple = np.array([1.0, 1.0])
         self._test_parameters = np.array([0.2, 0.5])
         self._test_bin_range = (-2.0, 2.0)
-        self._test_parameters_do_fit = np.array([0.2028599998043365, 0.5011616918536066])
-        self._test_parameters_do_fit_simple = np.array([0.20031512887278155, 0.4967236106961646])
+        self._test_parameters_do_fit = np.array([0.20292002, 0.50108339])
+        self._test_parameters_do_fit_simple = np.array([0.20032218, 0.49665461])
         self._test_x = np.array([-2.0, -1.5, -1.0, -0.5, 0.0, 0.5, 1.0, 1.5, 2.0])
         self._test_density_default = self.hist_model_density(self._test_x, *self._test_parameters_default)
         self._test_density_default_simple = self.hist_model_density(self._test_x, *self._test_parameters_default_simple)
@@ -258,7 +258,6 @@ class TestHistFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
             )
         )
         self.assertTrue(
-            True or
             np.allclose(
                 self._test_density_do_fit,
                 _read_fit.eval_model_function_density(self._test_x)
@@ -637,7 +636,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self.assertTrue(
             np.allclose(
                 self._test_parameters_default,
-                _read_fit.poi_values
+                _read_fit.parameter_values
             )
         )
         self.assertTrue(
@@ -652,7 +651,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self.assertTrue(
             np.allclose(
                 self._test_parameters_do_fit,
-                _read_fit.poi_values
+                _read_fit.parameter_values
             )
         )
         self.assertTrue(
@@ -668,7 +667,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self.assertTrue(
             np.allclose(
                 self._test_parameters_default_simple,
-                _read_fit.poi_values
+                _read_fit.parameter_values
             )
         )
         self.assertTrue(
@@ -683,7 +682,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self.assertTrue(
             np.allclose(
                 self._test_parameters_do_fit_simple,
-                _read_fit.poi_values
+                _read_fit.parameter_values
             )
         )
         self.assertTrue(
@@ -702,7 +701,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self.assertTrue(
             np.allclose(
                 self._test_parameters_default,
-                _read_fit.poi_values
+                _read_fit.parameter_values
             )
         )
         self.assertTrue(
@@ -717,7 +716,7 @@ class TestXYFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresenter):
         self.assertTrue(
             np.allclose(
                 self._test_parameters_do_fit,
-                _read_fit.poi_values
+                _read_fit.parameter_values
             )
         )
         self.assertTrue(
@@ -745,8 +744,7 @@ dataset:
          0.2081663284234683, -1.1066854012184062, 0.4121145273973152, 1.948498429389019, 1.4469448685636854,
          0.07981317629602669, 1.411704446184254, -0.4610151277847929, 0.9477286127925121, 0.08899785814182719]
 fixed_parameters:
-- - mu
-  - 0.1
+    mu: 0.1
 parametric_model:
     model_function:
         python_code: |
@@ -791,8 +789,7 @@ data: [1.0130614498386674, -1.1349287030839197, -0.10341784343652169, -1.3907686
 
 TEST_FIT_UNBINNED_MISSING_KEYWORD = """
 fixed_parameters:
-- - mu
-  - 0.1
+    mu: 0.1
 parametric_model:
     python_code: |
         def normal_distribution_pdf(x, mu, sigma):
@@ -835,7 +832,7 @@ class TestUnbinnedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresent
         self._test_parameters_default = np.array([0.1, 1.0])
         self._test_parameters_default_simple = np.array([1.0, 1.0])
         self._test_parameters_do_fit = np.array([0.1, 1.09727982])
-        self._test_parameters_do_fit_simple = np.array([-0.07072322, 1.02381907])
+        self._test_parameters_do_fit_simple = np.array([-0.07060323, 1.02375445])
 
         self._fit = UnbinnedFit(data=self._test_data, model_density_function='normal_distribution_pdf')
         self._fit.fix_parameter('mu', 0.1)
@@ -845,23 +842,25 @@ class TestUnbinnedFitYamlRepresenter(unittest.TestCase, AbstractTestFitRepresent
     def test_read_from_testfile_stream(self):
         _read_fit = self._testfile_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.poi_values))
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
         _read_fit.do_fit()
-        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.poi_values))
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
 
     def test_read_from_testfile_stream_simple(self):
         _read_fit = self._testfile_streamreader_simple.read()
 
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(np.allclose(self._test_parameters_default_simple, _read_fit.poi_values))
+        self.assertTrue(np.allclose(
+            self._test_parameters_default_simple, _read_fit.parameter_values))
         _read_fit.do_fit()
-        self.assertTrue(np.allclose(self._test_parameters_do_fit_simple, _read_fit.poi_values))
+        self.assertTrue(np.allclose(
+            self._test_parameters_do_fit_simple, _read_fit.parameter_values))
 
     def test_round_trip_with_stringstream(self):
         self._roundtrip_streamwriter.write()
         self._roundtrip_stringstream.seek(0)  # return to beginning
         _read_fit = self._roundtrip_streamreader.read()
         self.assertTrue(isinstance(_read_fit, self.FIT_CLASS))
-        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.poi_values))
+        self.assertTrue(np.allclose(self._test_parameters_default, _read_fit.parameter_values))
         _read_fit.do_fit()
-        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.poi_values))
+        self.assertTrue(np.allclose(self._test_parameters_do_fit, _read_fit.parameter_values))
